#[non_exhaustive]pub enum ChunkListenerFailureKind {
Error,
Panic,
}Expand description
Whether a chunk listener returned an error or panicked.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Error
The listener returned a classified error.
Panic
The listener panicked before or while its future was polled.