#[non_exhaustive]pub enum CursorError {
CursorInvalid,
CursorQueryMismatch,
}Expand description
A rejected continuation token.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CursorInvalid
The token was malformed, oversized, or failed its checksum.
CursorQueryMismatch
The token belongs to a different query, filter, or page size.