#[non_exhaustive]pub enum EventTiming {
AfterCommit,
AfterRead,
AfterEvidence,
RuntimeBoundary,
}Expand description
Stable timing of an event relative to the decision it observes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AfterCommit
Emitted after the governing durable commit returns successfully.
AfterRead
Emitted after a bounded read returns successfully.
AfterEvidence
Emitted after durable evidence is gathered and before it is returned.
RuntimeBoundary
Emitted when a non-durable runtime boundary is observed.