#[non_exhaustive]pub enum ExplorerQuery {
JobNames,
Instances {
job_name: JobName,
},
Executions {
job_instance_id: JobInstanceId,
},
StepExecutions {
job_execution_id: JobExecutionId,
},
UnresolvedExecutions {
minimum_age: Duration,
},
RecoveryDecisions {
job_execution_id: JobExecutionId,
},
FlowDecisions {
job_execution_id: JobExecutionId,
},
StepPartitions {
step_execution_id: StepExecutionId,
},
OperatorRequests {
job_execution_id: JobExecutionId,
},
}Expand description
The closed set of paginated explorer queries.
get_execution is the one named query that returns a single projection and
therefore takes no cursor.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
JobNames
Registered job names in byte order.
Instances
Instances of one job name, newest identity first.
Executions
Executions of one instance, newest attempt first.
Fields

job_instance_id: JobInstanceIdFiltered logical instance.
StepExecutions
Step executions of one job execution.
Fields

job_execution_id: JobExecutionIdFiltered job execution.
UnresolvedExecutions
Non-terminal executions older than a bounded age.
Fields

minimum_age: DurationMinimum durable age, at least MIN_UNRESOLVED_AGE.
RecoveryDecisions
Recovery decisions of one job execution.
Fields

job_execution_id: JobExecutionIdFiltered job execution.
FlowDecisions
Flow decisions of one job execution in sequence order.
Fields

job_execution_id: JobExecutionIdFiltered job execution.
StepPartitions
Partitions of one partitioned step execution.
Fields

step_execution_id: StepExecutionIdFiltered parent step execution.
OperatorRequests
Audited operator requests for one job execution.
Fields

job_execution_id: JobExecutionIdFiltered job execution.
Implementations