#[non_exhaustive]pub enum FlowExecutionOutcome {
Completed,
Stopped,
Unknown,
Failed(FlowFailure),
}Expand description
Why a durable flow attempt ended.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Completed
A Complete terminal was reached.
Stopped
A Stop terminal or cooperative stop was reached.
Unknown
The durable outcome is ambiguous and no transition was selected.
Failed(FlowFailure)
A step, decider, listener, mapping, or start control failed closed.