#[non_exhaustive]pub enum FlowJobError {
UnsupportedManifest {
format: u16,
},
JobNameMismatch,
WrongNodeKind {
node: NodeId,
},
StepNameMismatch {
node: NodeId,
},
DuplicateBinding {
node: NodeId,
},
MissingBinding {
node: NodeId,
},
ComponentMismatch {
node: NodeId,
},
FactoryPanic {
node: NodeId,
},
}Expand description
An executable component assembly that does not match its compiled plan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedManifest
General flows require canonical manifest format 2.
JobNameMismatch
The facade job name and manifest identity differ.
WrongNodeKind
The node is absent or has the other executable kind.
StepNameMismatch
The durable step name differs from the compiled declaration.
DuplicateBinding
A node was bound more than once.
MissingBinding
A compiled node has no executable component.
ComponentMismatch
The bound executable does not match the compiled step declaration.
FactoryPanic
A branch component factory panicked before durable launch.