#[non_exhaustive]pub enum IdGenerationError {
Exhausted {
kind: IdentifierKind,
},
Invalid(DomainError),
}Expand description
Failure from an injected identifier source.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exhausted
The source cannot issue another identifier of this kind.
Fields

kind: IdentifierKindThe identifier category that was requested.
Invalid(DomainError)
The source produced a value that violated a domain invariant.