#[non_exhaustive]pub enum JobInstanceSelection {
Created(JobInstance),
Existing(JobInstance),
}Expand description
The result of selecting the canonical instance for an identifying key.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Created(JobInstance)
This unit of work created the logical instance.
Existing(JobInstance)
The logical instance already existed.
Implementations
Sourceimpl JobInstanceSelection
impl JobInstanceSelection
Sourcepub const fn instance(&self) -> &JobInstance
pub const fn instance(&self) -> &JobInstance
Borrows the selected instance regardless of whether it was created.
Sourcepub const fn was_created(&self) -> bool
pub const fn was_created(&self) -> bool
Returns whether the instance was created by this operation.