#[non_exhaustive]pub enum LaunchError {
Repository(RepositoryError),
Flow(FlowSelectionError),
UnsupportedPlan,
InvalidStopPollInterval,
ShuttingDown,
}Expand description
A launch failure that prevented a final execution report.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Repository(RepositoryError)
Metadata creation, transition, or commit failed.
Flow(FlowSelectionError)
The compiled plan could not route a produced exit outcome.
UnsupportedPlan
The launcher was given a plan it cannot execute.
This launcher executes the one-step compatibility plan that
TaskletJob and ChunkJob lower into. Multi-node
graphs are executed by the durable-flow runtime.
InvalidStopPollInterval
The durable stop-poll interval was outside 100 ms..=60 s.
ShuttingDown
Process shutdown stopped intake before this launch was accepted.