LifecycleEventKind

Enum LifecycleEventKind 

#[non_exhaustive]
pub enum LifecycleEventKind {
Show 30 variants LaunchAccepted, JobStarting, StepStarting, JobStarted, StepStarted, JobStopping, StepStopping, JobStopped, StepStopped, JobCompleted, StepCompleted, JobFailed, StepFailed, JobUnknown, StepUnknown, ChunkStarted, ChunkCommitted, ChunkRolledBack, ChunkUnknown, JobBeforeListenerFailed, JobAfterListenerFailed, StepBeforeListenerFailed, StepAfterListenerFailed, RetryReserved, RetryBackoffStarted, RetryBackoffCancelled, RetryExhausted, ItemSkipped, FaultRollbackCommitted, FaultNoRollbackCommitted,
}
Stable M1 lifecycle event names.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


LaunchAccepted

The repository accepted a launch and created its execution graph.



JobStarting

Job metadata is durably STARTING.



StepStarting

Step metadata is durably STARTING.



JobStarted

Job metadata is durably STARTED.



StepStarted

Step metadata is durably STARTED.



JobStopping

Job metadata is durably STOPPING.



StepStopping

Step metadata is durably STOPPING.



JobStopped

Job metadata is durably STOPPED.



StepStopped

Step metadata is durably STOPPED.



JobCompleted

Job metadata is durably COMPLETED.



StepCompleted

Step metadata is durably COMPLETED.



JobFailed

Job metadata is durably FAILED.



StepFailed

Step metadata is durably FAILED.



JobUnknown

Job metadata is durably UNKNOWN.



StepUnknown

Step metadata is durably UNKNOWN.



ChunkStarted

A bounded chunk transaction is starting.



ChunkCommitted

A bounded chunk transaction committed.



ChunkRolledBack

A bounded chunk transaction rolled back.



ChunkUnknown

A chunk commit result is unknown.



JobBeforeListenerFailed

A job before-listener returned an error or panicked.



JobAfterListenerFailed

A job after-listener returned an error or panicked.



StepBeforeListenerFailed

A step before-listener returned an error or panicked.



StepAfterListenerFailed

A step after-listener returned an error or panicked.



RetryReserved

A retry ordinal became durably reserved.



RetryBackoffStarted

A cancellable backoff wait started.



RetryBackoffCancelled

Cooperative stop cancelled a backoff wait.



RetryExhausted

A retry budget is durably spent for one key.



ItemSkipped

A skip became authoritative in the accepting chunk commit.



FaultRollbackCommitted

A known rollback was classified by the fault policy.



FaultNoRollbackCommitted

A commit-safe skip committed without rolling back.

Implementations

Source

impl LifecycleEventKind

pub const fn telemetry_kind(self) -> TelemetryEventKind

Maps this legacy facade event into telemetry schema version 1.

pub const fn as_str(self) -> &'static str

Returns the stable dotted event name.

pub const fn component(self) -> EventComponent

Returns the component associated with the event.

pub const fn status(self) -> Option<BatchStatus>

Returns the lifecycle status represented by the event, when any.

pub const fn severity(self) -> EventSeverity

Returns the stable event severity.