#[non_exhaustive]pub enum OperatorAction {
Launch,
Restart,
Stop,
Abandon,
Recover,
}Expand description
A mutating action a deployment authorizes and the core guards.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Launch
Create the instance when required and one STARTING execution.
Restart
Create another execution attempt from the committed checkpoint.
Stop
Durably record a cooperative stop request.
Abandon
Make a stopped, failed, or recovered execution permanently terminal.
Recover
Append one evidence-bound recovery decision and apply its result.
Implementations