#[non_exhaustive]pub enum ShutdownRequest {
Initiated,
Escalated,
AlreadyEscalated,
}Expand description
Classification of one shutdown request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Initiated
The first request stopped intake and began cooperative cancellation.
Escalated
The second request stopped waiting for the join deadline.
AlreadyEscalated
Waiting had already been escalated.