#[non_exhaustive]pub enum StopTiming {
BeforeStart,
DuringExecution,
AfterBlockingWork,
}Expand description
Classifies when a cooperative stop was observed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BeforeStart
Stop was requested before user work started.
DuringExecution
An asynchronous tasklet observed stop while it was running.
AfterBlockingWork
Stop arrived after synchronous work started and was reported after it completed.