#[non_exhaustive]pub enum TaskletExecutionOutcome {
Completed,
Failed(TaskletFailure),
Stopped(StopTiming),
Unknown,
}Expand description
The stable execution result captured by a launch.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Completed
The job and step completed.
Failed(TaskletFailure)
The job and step failed at the tasklet boundary.
Stopped(StopTiming)
The job and step stopped cooperatively.
Unknown
A resource commit may or may not have reached durable storage.