#[non_exhaustive]pub enum TaskletFailure {
Error,
Panic,
ListenerError,
ListenerPanic,
}Expand description
Classifies a tasklet failure without exposing an error or panic payload.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Error
The tasklet returned TaskletError.
Panic
The tasklet panicked before or while its future was polled.
ListenerError
A listener returned a classified error.
ListenerPanic
A listener panicked at its framework boundary.