#[non_exhaustive]pub enum TelemetrySpanKind {
JobExecution,
StepExecution,
ChunkAttempt,
ItemRead,
ItemProcess,
ItemWrite,
RepositoryCommit,
Retry,
Backoff,
}Expand description
One stable span in the telemetry schema version 1 hierarchy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
JobExecution
The root span for one job execution attempt.
StepExecution
One step execution attempt below its job execution.
ChunkAttempt
One bounded chunk attempt below its step execution.
ItemRead
The read phase of a chunk attempt.
ItemProcess
The process phase of a chunk attempt.
ItemWrite
The write phase of a chunk attempt.
RepositoryCommit
The repository commit phase of a chunk attempt.
Retry
One retry attempt below its step execution.
Backoff
The bounded wait below one retry attempt.
Implementations
Sourceimpl TelemetrySpanKind
impl TelemetrySpanKind
Sourcepub const fn parent(self) -> Option<Self>
pub const fn parent(self) -> Option<Self>
Returns the required direct parent in the stable hierarchy.
Sourcepub const fn component(self) -> EventComponent
pub const fn component(self) -> EventComponent
Returns the framework component represented by this span.
Sourcepub const fn safe_field_keys(self) -> &'static [&'static str]
pub const fn safe_field_keys(self) -> &'static [&'static str]
Returns the complete reviewed field-key set for this span.