pub struct LifecycleTransition { /* private fields */ }Expand description
A requested framework lifecycle transition and its deterministic timestamp.
Implementations
Sourceimpl LifecycleTransition
impl LifecycleTransition
Sourcepub const fn new(
target: BatchStatus,
transitioned_at: SystemTime,
) -> LifecycleTransition
pub const fn new( target: BatchStatus, transitioned_at: SystemTime, ) -> LifecycleTransition
Requests a transition that does not introduce a failure.
Sourcepub const fn failed(
transitioned_at: SystemTime,
failure: FailureSummary,
) -> LifecycleTransition
pub const fn failed( transitioned_at: SystemTime, failure: FailureSummary, ) -> LifecycleTransition
Requests a transition to FAILED with a redacted failure summary.
Sourcepub const fn target(self) -> BatchStatus
pub const fn target(self) -> BatchStatus
Returns the requested framework status.
Sourcepub const fn transitioned_at(self) -> SystemTime
pub const fn transitioned_at(self) -> SystemTime
Returns the deterministic transition instant supplied by the caller.
Sourcepub const fn with_terminal_rollback(self) -> LifecycleTransition
pub const fn with_terminal_rollback(self) -> LifecycleTransition
Marks the transition as one whose terminal work was rolled back.