pub struct MetricDimensions { /* private fields */ }Expand description
A complete set of typed dimensions accepted by the metric catalog.
Implementations
Sourceimpl MetricDimensions
impl MetricDimensions
Sourcepub const fn with_event(self, value: TelemetryEventKind) -> Self
pub const fn with_event(self, value: TelemetryEventKind) -> Self
Adds one bounded event-name dimension.
Sourcepub const fn with_status(self, value: BatchStatus) -> Self
pub const fn with_status(self, value: BatchStatus) -> Self
Adds one lifecycle-status dimension.
Sourcepub const fn with_action(self, value: OperatorAction) -> Self
pub const fn with_action(self, value: OperatorAction) -> Self
Adds one operator-action dimension.
Adds one authorization-class dimension.
Sourcepub const fn with_outcome(self, value: OperatorOutcomeClass) -> Self
pub const fn with_outcome(self, value: OperatorOutcomeClass) -> Self
Adds one operator-outcome dimension.
Sourcepub fn with_job_name(self, value: JobName) -> Self
pub fn with_job_name(self, value: JobName) -> Self
Adds a validated job name, subject to the configured allowlist.
Sourcepub fn with_step_name(self, value: StepName) -> Self
pub fn with_step_name(self, value: StepName) -> Self
Adds a validated step name, subject to the configured allowlist.