pub struct OwnerToken(/* private fields */);Expand description
A per-process 16-byte execution-owner token.
The token is evidence only. It is not a lease, never expires, grants no authority, and must not be reused by another process.
Implementations
Sourceimpl OwnerToken
impl OwnerToken
Sourcepub const fn from_bytes(bytes: [u8; 16]) -> OwnerToken
pub const fn from_bytes(bytes: [u8; 16]) -> OwnerToken
Constructs a token from application-generated random bytes.