pub struct PartitionAggregate { /* private fields */ }Expand description
The deterministic result of aggregating one complete durable partition plan.
Implementations
Sourceimpl PartitionAggregate
impl PartitionAggregate
Sourcepub const fn status(&self) -> BatchStatus
pub const fn status(&self) -> BatchStatus
Returns the most severe child status.
Sourcepub const fn exit_status(&self) -> &ExitStatus
pub const fn exit_status(&self) -> &ExitStatus
Borrows the first matching exit status in partition-key byte order.
Sourcepub const fn counts(&self) -> ExecutionCounts
pub const fn counts(&self) -> ExecutionCounts
Returns the checked sum of every durable child counter.