pub struct PostgresDurableStepState { /* private fields */ }Expand description
Durable progress loaded for one PostgreSQL-backed step execution.
Implementations
Sourceimpl PostgresDurableStepState
impl PostgresDurableStepState
Sourcepub const fn step_execution(&self) -> &StepExecution
pub const fn step_execution(&self) -> &StepExecution
Borrows the step snapshot, including committed counters and version.
Sourcepub const fn checkpoint(&self) -> &Checkpoint
pub const fn checkpoint(&self) -> &Checkpoint
Borrows the last committed checkpoint.
Sourcepub const fn execution_context(&self) -> &ExecutionContext
pub const fn execution_context(&self) -> &ExecutionContext
Borrows the last committed execution context.
Sourcepub const fn fault_progress(&self) -> FaultProgress
pub const fn fault_progress(&self) -> FaultProgress
Returns the committed fault-tolerance totals of this attempt.
Sourcepub const fn fault_state(&self) -> &FaultStateEnvelope
pub const fn fault_state(&self) -> &FaultStateEnvelope
Borrows the validated unresolved retry state of this attempt.