pub struct QueryWindow { /* private fields */ }Expand description
The bounded keyset window one adapter statement must honour.
Implementations
Sourceimpl QueryWindow
impl QueryWindow
Sourcepub const fn after(&self) -> Option<&CursorKey>
pub const fn after(&self) -> Option<&CursorKey>
Borrows the exclusive ordering key of the previous page, when present.