pub struct RecoveryMarkers(/* private fields */);Expand description
Closed boolean recovery markers retained as one bounded bit set.
Implementations
Sourceimpl RecoveryMarkers
impl RecoveryMarkers
Sourcepub const fn new() -> RecoveryMarkers
pub const fn new() -> RecoveryMarkers
Constructs an empty marker set.
Sourcepub const fn with_unknown_commit(self, value: bool) -> RecoveryMarkers
pub const fn with_unknown_commit(self, value: bool) -> RecoveryMarkers
Records whether the last durable marker is an unknown commit.
Sourcepub const fn with_completed_partition(self, value: bool) -> RecoveryMarkers
pub const fn with_completed_partition(self, value: bool) -> RecoveryMarkers
Records whether completed partition evidence exists.
Sourcepub const fn with_committed_flow_decision(self, value: bool) -> RecoveryMarkers
pub const fn with_committed_flow_decision(self, value: bool) -> RecoveryMarkers
Records whether a committed flow decision exists.
Sourcepub const fn with_ambiguous_external_effect(
self,
value: bool,
) -> RecoveryMarkers
pub const fn with_ambiguous_external_effect( self, value: bool, ) -> RecoveryMarkers
Records whether the definition declares an ambiguous external effect.