pub struct TelemetryExporter<S> { /* private fields */ }Expand description
Drains one queue from an application-owned task.
Implementations
Sourceimpl<S: TelemetryExportSink> TelemetryExporter<S>
impl<S: TelemetryExportSink> TelemetryExporter<S>
Sourcepub const fn new(queue: TelemetryQueue, sink: S) -> Self
pub const fn new(queue: TelemetryQueue, sink: S) -> Self
Binds a queue to an adapter without spawning any task.
Sourcepub async fn flush(&self) -> ExportFlushReport
pub async fn flush(&self) -> ExportFlushReport
Drains every currently queued record and isolates adapter failures.